<?php
namespace SmartGallery\Site\BlockLayout;

use Omeka\Api\Representation\SiteRepresentation;
use Omeka\Api\Representation\SitePageRepresentation;
use Omeka\Api\Representation\SitePageBlockRepresentation;
use Omeka\Site\BlockLayout\AbstractBlockLayout;
use Laminas\View\Renderer\PhpRenderer;

use Laminas\Form\FormElementManager;

use SmartGallery\Form\SmartGalleryBlockForm;

class SmartGallery extends AbstractBlockLayout
{
	/**
     * @var FormElementManager
     */
    protected $formElementManager;

    /**
     * @var array
     */
	protected $defaultSettings = [];

    /**
     * @param FormElementManager $formElementManager
     * @param array $defaultSettings
     */
    public function __construct(FormElementManager $formElementManager, array $defaultSettings)
    {
        $this->formElementManager = $formElementManager;
        $this->defaultSettings = $defaultSettings;
    }

	public function getLabel() {
		return 'Smart gallery';
	}

	public function form(PhpRenderer $view,
                       SiteRepresentation $site,
                       SitePageRepresentation $page = null,
                       SitePageBlockRepresentation $block = null
    ) {
		$form = $this->formElementManager->get(SmartGalleryBlockForm::class);
		$data = $block
			? $block->data() + $this->defaultSettings
			: $this->defaultSettings;
		$form->setData([
			'o:block[__blockIndex__][o:data][title]' => $data['title'],
      'o:block[__blockIndex__][o:data][renderSourceLink]' => $data['renderSourceLink'],
		]);
		$form->prepare();

		$html = '';
		$html .= $view->blockAttachmentsForm($block);
		$html .= '<a href="#" class="collapse" aria-label="collapse"><h4>';
    $html .= $view->translate('Options'). '</h4></a>';
		$html .= '<div class="collapsible" style="padding-top:6px;">';
		$html .= $view->formCollection($form);
    $html .= '</div>';
		return $html;
    }

	public function render(PhpRenderer $view, SitePageBlockRepresentation $block)
	{
		$attachments = $block->attachments();
        if (!$attachments) {
            return '';
		}

    //$thumbnails = [];
		static $gallery_id = 0;
    $images = [];

    /*
    $media = $attachments[0]->item()->media()[0];
    $item = $attachments[0]->item();
    $item_url = null;
    if ($block->dataValue('renderSourceLink')) {
      $item_url = $attachments[0]->item()->url();
    }
    */

    foreach ($attachments as $attachment)
		{
      $img_id = 0;
			foreach($attachment->item()->media() as $media)
			{
				$mediaType = $media->mediaType();
				$mediaRenderer = $media->renderer();
				if ((strpos($mediaType, 'image/') !== false) || (strpos($mediaRenderer, 'youtube') !== false)) {
					array_push($images, ["media_url" => $media->originalUrl(),
                               "item_url" => $attachment->item()->url(),
                               "image_title" => $media->title(),
                               "img_id" => 'gi_' . $gallery_id . '_' . $img_id,
                              ]);
          $img_id = $img_id +1;
				}
			}
		}
		return $view->partial('common/block-layout/smartGallery', [
      'gallery_id' => 'ig_' . ++$gallery_id,
			'title' => $block->dataValue('title'),
      'images' => $images,
      'renderSourceLink' => $block->dataValue('renderSourceLink'),
		]);
	}
}
